==> vertx-up-0.4.8-sources.jar: io/vertx/up/rs/dispatch/IpcDiffer.java <==
package io.vertx.up.rs.dispatch;

import io.vertx.ext.web.RoutingContext;
import io.vertx.up.atom.agent.Event;
import io.vertx.up.func.Fn;
import io.vertx.up.log.Annal;
import io.vertx.up.rs.Aim;
import io.vertx.up.rs.hunt.IpcAim;
import io.vertx.up.tool.mirror.Instance;
import io.vertx.zero.exception.ReturnTypeException;

import java.lang.reflect.Method;

class IpcDiffer implements Differ<RoutingContext> {

    private static final Annal LOGGER = Annal.get(IpcDiffer.class);

    private static Differ<RoutingContext> INSTANCE = null;

    public static Differ<RoutingContext> create() {
        if (null == INSTANCE) {
            synchronized (EventDiffer.class) {
                if (null == INSTANCE) {
                    INSTANCE = new IpcDiffer();
                }
            }
        }
        return INSTANCE;
    }

    private IpcDiffer() {
    }

    @Override
    public Aim<RoutingContext> build(final Event event) {
        final Method method = event.getAction();
        final Class<?> returnType = method.getReturnType();
        // Rpc Mode only
        Aim<RoutingContext> aim = null;
        if (Void.class == returnType || void.class == returnType) {
            // Exception because this method must has return type to
            // send message to event bus. It means that it require
            // return types.
            Fn.flingUp(true, LOGGER, ReturnTypeException.class,
                    getClass(), method);
        } else {
            // Mode 6: Ipc channel enabled
            aim = Fn.pool(Pool.AIMS, Thread.currentThread().getName() + "-mode-ipc",
                    () -> Instance.instance(IpcAim.class));
        }
        return aim;
    }
}

==> vertx-up-0.4.10-sources.jar: io/vertx/up/rs/dispatch/IpcDiffer.java <==
package io.vertx.up.rs.dispatch;

import io.vertx.ext.web.RoutingContext;
import io.vertx.up.atom.agent.Event;
import io.vertx.up.log.Annal;
import io.vertx.up.rs.Aim;
import io.vertx.up.rs.hunt.IpcAim;
import io.vertx.zero.exception.ReturnTypeException;
import io.zero.epic.Ut;
import io.zero.epic.fn.Fn;

import java.lang.reflect.Method;

class IpcDiffer implements Differ<RoutingContext> {

    private static final Annal LOGGER = Annal.get(IpcDiffer.class);

    private static Differ<RoutingContext> INSTANCE = null;

    private IpcDiffer() {
    }

    public static Differ<RoutingContext> create() {
        if (null == INSTANCE) {
            synchronized (EventDiffer.class) {
                if (null == INSTANCE) {
                    INSTANCE = new IpcDiffer();
                }
            }
        }
        return INSTANCE;
    }

    @Override
    public Aim<RoutingContext> build(final Event event) {
        final Method method = event.getAction();
        final Class<?> returnType = method.getReturnType();
        // Rpc Mode only
        Aim<RoutingContext> aim = null;
        if (Void.class == returnType || void.class == returnType) {
            // Exception because this method must has return type to
            // send message to event bus. It means that it require
            // return types.
            Fn.outUp(true, LOGGER, ReturnTypeException.class,
                    this.getClass(), method);
        } else {
            // Mode 6: Ipc channel enabled
            aim = Fn.pool(Pool.AIMS, Thread.currentThread().getName() + "-mode-ipc",
                    () -> Ut.instance(IpcAim.class));
        }
        return aim;
    }
}
